from collections import OrderedDict

from .. import Provider as PersonProvider


class Provider(PersonProvider):
    # weights are arbitrarily assigned
    formats = OrderedDict((
        ("{{first_name}} {{last_name}}", 0.97),
        ("{{prefix}}{{first_name}} {{last_name}}", 0.015),
        ("{{prefix}}{{first_name}} {{last_name}} {{suffix}}", 0.02),
        ("{{first_name}} {{last_name}} {{suffix}}", 0.005),
    ))

    # Thai prefix, adapted from
    # http://www.stou.ac.th/thai/grad_stdy/Apply/prefix.asp
    # weights are arbitrarily assigned
    prefixes_female = OrderedDict((
        ("นาง", 0.3),
        ("น.ส.", 0.2),
        ("นางสาว", 0.15),
        ("ด.ญ.", 0.15),
        ("เด็กหญิง", 0.05),
        ("จ.ต.", 0.001),
        ("จ.ท.", 0.001),
        ("จ.ส.ต.", 0.001),
        ("จ.ส.ท.", 0.001),
        ("จ.ส.อ.", 0.001),
        ("จ.อ.", 0.001),
        ("ด.ต.", 0.001),
        ("น.ต.", 0.001),
        ("น.ท.", 0.001),
        ("น.อ.", 0.001),
        ("พ.จ.ต.", 0.001),
        ("พ.จ.ท.", 0.001),
        ("พ.จ.อ.", 0.001),
        ("พ.ต.", 0.001),
        ("พ.ต.ต.", 0.001),
        ("พ.ต.ท.", 0.001),
        ("พ.ต.อ.", 0.001),
        ("พ.ท.", 0.001),
        ("พ.อ.", 0.001),
        ("พ.อ.ต.", 0.001),
        ("พ.อ.ท.", 0.001),
        ("พ.อ.อ.", 0.001),
        ("ร.ต.", 0.001),
        ("ร.ต.ต.", 0.001),
        ("ร.ต.ท.", 0.001),
        ("ร.ต.อ.", 0.001),
        ("ร.ท.", 0.001),
        ("ร.อ.", 0.001),
        ("ส.ต.", 0.001),
        ("ส.ต.ต.", 0.001),
        ("ส.ต.ท.", 0.001),
        ("ส.ต.อ.", 0.001),
        ("ส.ท.", 0.001),
        ("ส.อ.", 0.001),
        ("พล.ต.", 0.0001),
        ("พล.ต.ต.", 0.0001),
        ("พล.ต.ท.", 0.0001),
        ("พล.ต.อ.", 0.0001),
        ("พล.ท.", 0.0001),
        ("พล.ร.ต.", 0.0001),
        ("พล.ร.ท.", 0.0001),
        ("พล.ร.อ.", 0.0001),
        ("พล.อ.", 0.0001),
        ("พล.อ.ต.", 0.0001),
        ("พล.อ.ท.", 0.0001),
        ("พล.อ.อ.", 0.0001),
        ("ม.ร.ว.", 0.0001),
        ("ม.ล.", 0.0001),
        ("หม่อมราชวงศ์", 0.0001),
        ("หม่อมหลวง", 0.0001),
    ))

    prefixes_male = OrderedDict((
        ("นาย", 0.6),
        ("ด.ช.", 0.3),
        ("จ.ต.", 0.001),
        ("จ.ท.", 0.001),
        ("จ.ส.ต.", 0.001),
        ("จ.ส.ท.", 0.001),
        ("จ.ส.อ.", 0.001),
        ("จ.อ.", 0.001),
        ("ด.ต.", 0.001),
        ("น.ต.", 0.001),
        ("น.ท.", 0.001),
        ("น.อ.", 0.001),
        ("พ.จ.ต.", 0.001),
        ("พ.จ.ท.", 0.001),
        ("พ.จ.อ.", 0.001),
        ("พ.ต.", 0.001),
        ("พ.ต.ต.", 0.001),
        ("พ.ต.ท.", 0.001),
        ("พ.ต.อ.", 0.001),
        ("พ.ท.", 0.001),
        ("พ.อ.", 0.001),
        ("พ.อ.ต.", 0.001),
        ("พ.อ.ท.", 0.001),
        ("พ.อ.อ.", 0.001),
        ("ร.ต.", 0.001),
        ("ร.ต.ต.", 0.001),
        ("ร.ต.ท.", 0.001),
        ("ร.ต.อ.", 0.001),
        ("ร.ท.", 0.001),
        ("ร.อ.", 0.001),
        ("ส.ต.", 0.001),
        ("ส.ต.ต.", 0.001),
        ("ส.ต.ท.", 0.001),
        ("ส.ต.อ.", 0.001),
        ("ส.ท.", 0.001),
        ("ส.อ.", 0.001),
        ("พล.ต.", 0.0001),
        ("พล.ต.ต.", 0.0001),
        ("พล.ต.ท.", 0.0001),
        ("พล.ต.อ.", 0.0001),
        ("พล.ท.", 0.0001),
        ("พล.ร.ต.", 0.0001),
        ("พล.ร.ท.", 0.0001),
        ("พล.ร.อ.", 0.0001),
        ("พล.อ.", 0.0001),
        ("พล.อ.ต.", 0.0001),
        ("พล.อ.ท.", 0.0001),
        ("พล.อ.อ.", 0.0001),
        ("ม.ร.ว.", 0.0001),
        ("ม.ล.", 0.0001),
        ("หม่อมราชวงศ์", 0.0001),
        ("หม่อมหลวง", 0.0001),
        ("พระ", 0.0001),
        ("สามเณร", 0.001),
        ("พระครูธรรมธร", 0.00001),
        ("พระครูปลัด", 0.00001),
        ("พระครูวินัยธร", 0.00001),
        ("พระครูสมุห์", 0.00001),
        ("พระครูใบฎีกา", 0.00001),
        ("พระปลัด", 0.00001),
        ("พระมหา", 0.00001),
        ("พระสมุห์", 0.00001),
        ("พระอธิการ", 0.00001),
        ("พระใบฎีกา", 0.00001),
        ("เจ้าอธิการ", 0.00001),
    ))

    prefixes = prefixes_female.copy()
    prefixes.update(prefixes_male)

    # first name partially from
    # Chulalongkorn University famous teacher & student first name
    # https://th.wikipedia.org/wiki/%E0%B8%A3%E0%B8%B2%E0%B8%A2%E0%B8%99%E0%B8%B2%E0%B8%A1%E0%B8%9A%E0%B8%B8%E0%B8%84%E0%B8%84%E0%B8%A5%E0%B8%88%E0%B8%B2%E0%B8%81%E0%B8%88%E0%B8%B8%E0%B8%AC%E0%B8%B2%E0%B8%A5%E0%B8%87%E0%B8%81%E0%B8%A3%E0%B8%93%E0%B9%8C%E0%B8%A1%E0%B8%AB%E0%B8%B2%E0%B8%A7%E0%B8%B4%E0%B8%97%E0%B8%A2%E0%B8%B2%E0%B8%A5%E0%B8%B1%E0%B8%A2
    # and
    # https://github.com/PyThaiNLP/pythainlp/blob/dev/pythainlp/corpus/person_names_female_th.txt
    # https://github.com/PyThaiNLP/pythainlp/blob/dev/pythainlp/corpus/person_names_male_th.txt
    first_names = (
        "กมล",
        "กรกันต์",
        "กรรณิการ์",
        "กริช",
        "กฤชภร",
        "กฤตยา",
        "กฤษฎา",
        "กฤษดา",
        "กฤษนะ",
        "กอบชัย",
        "กอบศักดิ์",
        "กัญรภัส",
        "กันต์",
        "กานธนิกา",
        "การะเกด",
        "กิตตินันท์",
        "กิตติพงษ์",
        "กุลนัดดา",
        "กุลนิจ",
        "กุศล",
        "กุศล",
        "กุสนี",
        "เกริก",
        "เกรียงไกร",
        "เกรียงเดช",
        "เกษรา",
        "เกษศิรินทร์",
        "โกเมน",
        "ขวัญข้าว",
        "ขัตติยะ",
        "ขัตติยา",
        "เขมิณทรา",
        "แขมมณี",
        "คงสง",
        "คณะณัฐ",
        "คณาธิป",
        "คณิต",
        "คมกฤษ",
        "คำแข่ง",
        "คีรติ",
        "งามนิตย์",
        "จรรยานี",
        "จักรพงศ์",
        "จักรพันธ์",
        "จันทร์พิมพ์",
        "จันทรา",
        "จันทิมา",
        "จารุณี",
        "จำเนียร",
        "จำลอง",
        "จิตติมา",
        "จิระ",
        "จิรัฐิติ",
        "จีรศักดิ์",
        "จุฑาวุฒิ",
        "จุรินทร์",
        "จุฬิน",
        "ฉัตรปวีณ์",
        "ฉัตรวัชร์",
        "ฉันทวิชช์",
        "ชญาภา",
        "ชฎาทิพ",
        "ชนกนันท์",
        "ชนม์ทิดา",
        "ชนาธิป",
        "ชนิตา",
        "ชนิสาร์",
        "ชยกร",
        "ชยาวุธ",
        "ชยิศา",
        "ชลวิไล",
        "ชลอ",
        "ชลิตา",
        "ช่วงโชติ",
        "ชวฤทธิ์",
        "ชัชมาภรณ์",
        "ชัญญานุช",
        "ชัยชน",
        "ชัยณรงค์",
        "ชาญชัย",
        "ชารีฟ",
        "ชีวะเกตุ",
        "ชุติรัตน์",
        "ชุติวงศ์",
        "ชูกัน",
        "ชูเกียรติ",
        "โชคชัย",
        "โชติพิพัฒน์",
        "ซัลมีซา",
        "ฎาริกา",
        "ฐนิตนันท์",
        "ฐิตาชลีข์",
        "ฐิติมา",
        "ณชัย",
        "ณภศศิ",
        "ณรงค์",
        "ณรงค์",
        "ณรัณธกรณ์",
        "ณัฐจักร",
        "ณัฐฑิกานต์",
        "ณัฐ",
        "ณัฐวลัย",
        "ณัฐสิทธิ์",
        "ณัฐหทัย",
        "ณัทกาญจน์",
        "ณิชานันท์",
        "ดวงใจ",
        "ดวงเนตร",
        "ดารณี",
        "ดำริห์",
        "ดุจฤดี",
        "ดุสิตสิน",
        "ดุสิตา",
        "เดชดำรง",
        "ติงสมิตร",
        "เตชานันท์",
        "ถาวร",
        "เถลิงเดช",
        "ทรงยศ",
        "ทวิช",
        "ทวีพงศ์",
        "ทวียศ",
        "ทองปาน",
        "ทักษอร",
        "เทียนบุญ",
        "ธนกิจ",
        "ธนชัย",
        "ธนพร",
        "ธนพล",
        "ธนพันธ์",
        "ธนะชัย",
        "ธนันต์ธรญ์",
        "ธนาธร",
        "ธนิตพล",
        "ธนู",
        "ธภัทร",
        "ธรณินทร์",
        "ธวัชชัย",
        "ธัชกร",
        "ธัญชนก",
        "ธัญญา",
        "ธัญฤทธิ์",
        "ธัญสิทธิ์",
        "ธันย์ชนก",
        "ธารา",
        "ธาราภูมิ",
        "ธำรง",
        "ธิติมา",
        "ธิปัตยา",
        "ธีมะ",
        "ธีรภัทธ์",
        "ธีรัตถ์",
        "ธีราทัต",
        "นงลักษณ์",
        "นนทกานต์",
        "นพเก้า",
        "นภารัตน์",
        "นฤเทพ",
        "นลินี",
        "นวลพรรณ",
        "นันทวัฒน์",
        "นันทศักดิ์",
        "นันทิญา",
        "นิติมา",
        "นิติสิริ",
        "นิธิวัฒน์",
        "นิพนธ์",
        "นิพาดา",
        "นิรมล",
        "นิรมล",
        "นุชชาลี",
        "นุชอนงค์",
        "นูรฟานา",
        "นูรูมัน",
        "บดี",
        "บรรจง",
        "บวรศักดิ์",
        "บุญเชียร",
        "บุญถึง",
        "บุญทอง",
        "บุญพิทักษ์",
        "บุญยงค์",
        "บุญยอด",
        "บุญเลื่อน",
        "บุญส่ง",
        "บุญเหนือ",
        "บุรพรัตน์",
        "บุษกร",
        "บุหงา",
        "ปกป้อง",
        "ปฏิญญา",
        "ปทีป",
        "ปรมัตต์",
        "ปรวรรษ",
        "ประกายพรึก",
        "ประดิษฐ์",
        "ประเทืองวุฒิ",
        "ประภัทร์",
        "ประมวล",
        "ประโมทย์",
        "ประยูร",
        "ประวีณมัย",
        "ประเวช",
        "ประสงค์",
        "ประสิทธิ์",
        "ประเสริฐศรี",
        "ปราโมช",
        "ปริศนา",
        "ปรีชา",
        "ปรียาพร",
        "ปวีณ์นุช",
        "ปวีณ์นุนาย",
        "ปวีณ",
        "ปวีณ์สุดา",
        "ปองภพ",
        "ปัณย์วีร์",
        "ปาจรีย์",
        "ปาณิสรา",
        "ปานจิตร",
        "ปาลีรัตน์",
        "ปิยณี",
        "ปิยะชาติ",
        "ปิยะพันธ์",
        "ปิยะรัตน์",
        "พงศ์พิสุทธิ์",
        "พชร",
        "พรสิทธิ์",
        "พลอย",
        "พสุธา",
        "พัชชริน",
        "พัชทนัน",
        "พัชรศรี",
        "พัชฤนาถ",
        "พัฒนะชัย",
        "พันธมิตร",
        "พันธุ์เลิศ",
        "พาดีล๊ะ",
        "พาลุสุข",
        "พิชยา",
        "พิชัยยุทธ์",
        "พิบูลย์รัฐ",
        "พิมพ์มาดา",
        "พิมพิกา",
        "พิรุณรักษ์",
        "พิศาล",
        "พิสมัย",
        "พิสิทธิ์",
        "พุดตาล",
        "พุทธชาด",
        "เพ็ชรา",
        "ไพฑูรย์",
        "ไพบูลย์",
        "ไพโรจน์",
        "ไพศิษฐ์",
        "ฟองสนาน",
        "ภริดา",
        "ภัทร",
        "ภัทร",
        "ภัทรวี",
        "ภัทราคม",
        "ภัทรียา",
        "ภานุเดช",
        "ภานุภาค",
        "ภาวิตา",
        "ภีรเดช",
        "ภูมิไท",
        "ภูมิพัฒน์",
        "ภูมิ",
        "มณฑิตา",
        "มโน",
        "มะบูรฮัน",
        "มัณฑนา",
        "มาธวี",
        "มานพ",
        "มาศดิตถ์",
        "มาหะมะสายูตี",
        "มิ่งขวัญ",
        "มิตรศิลป์",
        "มิรันตี",
        "เมณฑกา",
        "เมตตา",
        "เมธินี",
        "เมลิษา",
        "เมษ",
        "ยงยุทธ",
        "ยรรยง",
        "ยิ่งพันธ์",
        "ยุทธนา",
        "ยุวศิริ",
        "โยฮัน",
        "รวีภัทร์",
        "รสสุคนธ์",
        "รอแม",
        "รังสิมาศ",
        "รัชชาภร",
        "รัชชา",
        "รัชวิน",
        "รัฐนันท์",
        "รัมภ์รดา",
        "เริงชัย",
        "เรืองโรจน์",
        "ฤทัย",
        "ลักษณา",
        "ลัดพลี",
        "เลอศักดิ์",
        "เลิศนภา",
        "เลิศศักดิ์",
        "ฦาไชย",
        "วงศกร",
        "วรพิศ",
        "วรรณวรงค์",
        "วรรณา",
        "วรรณา",
        "วรรษพร",
        "วรวงค์",
        "วรินทร",
        "วรินทร",
        "วรุธ",
        "วศิน",
        "วัฒนกร",
        "วัฒนา",
        "วันชัย",
        "วัลลภ",
        "วิจิตร",
        "วิชชพัชร์",
        "วิชัยยุตม์",
        "วิชัย",
        "วิทยา",
        "วิภาวี",
        "วิราภรณ์",
        "วิรุฬห์รักษ์",
        "วิษณุ",
        "วิสิฐ",
        "วีระพงษ์",
        "วีระศักดิ์",
        "ศจีพันธ์",
        "ศรัณย์ทร",
        "ศรีจิตรา",
        "ศรีหล้า",
        "ศศิวรรณ์",
        "ศักดา",
        "ศักดิ์ศิริ",
        "ศิระรังษี",
        "ศิริจิตร",
        "ศิรินทร์ทิพย์",
        "ศิริพร",
        "ศิริพิชยา",
        "ศิริวิมล",
        "ศีลวัต",
        "ศึกษา",
        "ศุภดิตถ์",
        "ศุภเดช",
        "ศุภพงศ์",
        "ศุรุท",
        "เศรษฐศิริ",
        "สกาวรัตน์",
        "สดศรี",
        "สนุก",
        "สมพงษ์",
        "สมพร",
        "สมพล",
        "สมภพ",
        "สมรัตน์",
        "สมหมาย",
        "สมหวัง",
        "สมัญญา",
        "สมัย",
        "สรสิทธิ์",
        "สรุโฆษิต",
        "สวรรยา",
        "สันชัย",
        "สันติ",
        "สันติ",
        "สาคร",
        "สามารถ",
        "สามารถ",
        "สายทิพย์",
        "สายัณห์",
        "สาลินี",
        "สาลูดิน",
        "สาวนูรอนีย์",
        "สำเร็จ",
        "สำลี",
        "สิครินทร์",
        "สิทธิพงษ์",
        "สิทธิหล่อ",
        "สิทธีอมร",
        "สิริพงษ์",
        "สิริภาธร",
        "สิริยากร",
        "สิโรรส",
        "สุกัญญา",
        "สุจินันท์",
        "สุชาดา",
        "สุชีวะ",
        "สุทธิชัย",
        "สุทธิ",
        "สุทัตตา",
        "สุทาทิพย์",
        "สุธรรม",
        "สุธรรม",
        "สุนทร",
        "สุนิดา",
        "สุนีย์",
        "สุนีย์",
        "สุพิชฌาย์",
        "สุภเดช",
        "สุภิญญา",
        "สุภิษา",
        "สุมล",
        "สุรเกียรติ์",
        "สุรพล",
        "สุรภา",
        "สุรางค์",
        "สุริพล",
        "สุวรรณ",
        "สุวลักษณ์",
        "สุวิชช์",
        "สุวิชญ",
        "สุวิชา",
        "สุวิมล",
        "สู่ขวัญ",
        "เสมอกัน",
        "เสริมคุณ",
        "เสาวณี",
        "เสาวภาพ",
        "แสงสนิท",
        "โสภา",
        "หมอนชัย",
        "หยุด",
        "หรรษา",
        "หฤหรรษ์",
        "หลุยส์",
        "หิรัญญา",
        "อณัฐชัย",
        "อดิสรณ์",
        "อดิสรณ์",
        "อธิรัตน์",
        "อนันดา",
        "อนันดา",
        "อนันต์",
        "อนิตษา",
        "อนุมัติ",
        "อนุรัตน์",
        "อโนทัย",
        "อภัสรดา",
        "อภิชาต",
        "อภิไท",
        "อมรวิชช์",
        "อมร",
        "อมาลีนา",
        "อรพรรณ",
        "อรุโณชา",
        "อ่องจริต",
        "อ่อนสา",
        "อ่อนอุษา",
        "อังษณา",
        "อัญชนา",
        "อัฎฐพล",
        "อับดุลบาซิร",
        "อับดุลอาเด็ล",
        "อัมพร",
        "อัศม์เดนาย",
        "อัษฎาวุธ",
        "อาทิตยาพร",
        "อาทิวราห์",
        "อานีซะห์",
        "อาภัสรา",
        "อาภาภัทร",
        "อิฐหรอเหม",
        "อิทธิพงศ์",
        "อุนนดา",
        "เอกธนา",
        "ไอยวริญท์",
        "ฮัมเสียะ",
        "ฮาวาติฟ",
    )

    # last name that has given by senior officer
    # http://www.reurnthai.com/index.php?topic=5273.45
    last_names = (
        "ดำริห์ชอบ",
        "ดวงทับทิม",
        "ดิศดใน",
        "ดัตพันธุ์",
        "ดุษฎีวนิช",
        "ดาบเพ็ชร์",
        "ดิสกะประกาย",
        "เดชคุ้ม",
        "ดาวกระจาย",
        "ดาบเงิน",
        "ดีตพันธุ์",
        "ดุริยพันธุ์",
        "ดาวอร่าม",
        "เดชวา",
        "ติระคมน์",
        "ไตรบรรพ",
        "ตระกูลบุญ",
        "เตมิยะเดช",
        "ตวงทอง",
        "แต้กุล",
        "ตรีครุธพันธุ์",
        "ตัณฑนุช",
        "ตั้งกุลงาม",
        "ตระกูลไม้เรียง",
        "ตะละภัฏ",
        "ตั้งเผ่า",
        "ตันเผ่า",
        "เตชะกำพุ",
        "ตัณสถิตย์",
        "ตราชู",
        "ตวันเยี่ยม",
        "ตรีเภรินทร์",
        "ตันตราจิณ",
        "ตั้งรบ",
        "ถนัดกลึง",
        "ถนอมมนุษย์",
        "ถนัดอักษร",
        "ถนัดการยนต์",
        "ถนัดหัดถกรรม",
        "ถาวรายุศม์",
        "ถนัดการเขียน",
        "ถาวรรัตน",
        "ถนัดพิมพการ",
        "ถ้วนศรี",
        "ถนอมพล",
        "ถาวระวรณ์",
        "ถนัดรบ",
        "ถนอมกุลบุตร",
        "ถมปัด",
        "ถนัดภาษา",
        "ถนัดเดินข่าว",
        "ถนัดรักษา",
        "ถนิมมาศ",
        "ถมังรักษสัตว์",
        "แถมธน",
        "ถะเกิงชศ",
        "ถิรสวัสดิ์",
        "ถนัดอาวุธ",
        "ถุงเงิน",
        "ทุมะบุตร์",
        "ทองประดิฐ",
        "ทรงโกมล",
        "ทัศนสุทธิ",
        "ทหารแท้",
        "ทองอยู่",
        "ทำประดู่",
        "ทรัพย์สาร",
        "ทีฆะ",
        "ทวนทอง",
        "ไทยสุชาต",
        "ทันยุค",
        "ไทนิยม",
        "ทองลาภ",
        "ทองเนื้อดี",
        "ทองแท้",
        "ทวีเดช",
        "ทับทิมไทย",
        "ทองสินธุ์",
        "ไทไชโย",
        "ทวนไชย์",
        "ทองสุกเลิศ",
        "ไทยแท้",
        "ทองสีไพล",
        "ธรรมนิยม",
        "ธนประทีป",
        "ธรรมเมธา",
        "ธุวะนุติ์",
        "ธาราธร",
        "ธีวร",
        "ธัญเสถียร",
        "ธนูปกรณ์",
        "เธียรายัน",
        "ธรรมฤดี",
        "ธัญาโภชน์",
        "ธนรักษ์",
        "ธูปะวิโรจน์",
        "ธูปหอม",
        "แนวพนิช",
        "นักสำหรวจ",
        "นฤทุกข์",
        "นาฏคายี",
        "เนื่องนนท์",
        "น้ำทิพย์",
        "เนื้อนุ่ม",
        "นวลฉวี",
        "นาคพันธุ์",
        "นำธวัช",
        "แน่นดุจป้อม",
        "เณรานุสนธิ์",
        "นามเสวตร",
        "นิษประปัญจ์",
        "นิระหานี",
        "นิลสุวรรณ์",
        "นักรบ",
        "นิติสาขา",
        "นิยมธรรม",
        "นิลเสนา",
        "หนุนสุข",
        "นิลวิมล",
        "นฤภัย",
        "นาถะเดชะ",
        "นพตระกูล",
        "นิยมเซียม",
        "หนักแน่น",
        "นามขำ",
        "นานายน",
        "นับเนื่องนอ",
        "แนวพญา",
        "นาถะพินธุ",
        "นิลสลัว",
        "นะวะมันดร",
        "นิลวรรณ",
        "เนตร์มณี",
        "นุตตาร",
        "นิยมสำหรวจ",
        "นกทอง",
        "นุชแนวนุ่ม",
        "นาคสุทิน",
        "นพคเชนทร์",
        "นาคะนคร",
        "นิละทัต",
        "นาควงษ์",
        "นากกนก",
        "บุนยาภิสนท์",
        "บุญญาภิรมย์",
        "บุณยะภาชน์",
        "บินดี",
        "บุนยะศัพท์",
        "บุนยะตีรณะ",
        "บุญญาไลย์",
        "บุญบำรุง",
    )

    # thai suffix that has given by the king
    # https://th.wikipedia.org/wiki/%E0%B8%99%E0%B8%B2%E0%B8%A1%E0%B8%AA%E0%B8%81%E0%B8%B8%E0%B8%A5%E0%B8%9E%E0%B8%A3%E0%B8%B0%E0%B8%A3%E0%B8%B2%E0%B8%8A%E0%B8%97%E0%B8%B2%E0%B8%99
    suffixes = (
        "ณ กาฬสินธุ์",
        "ณ จัมปาศักดิ์",
        "ณ เชียงใหม่",
        "ณ ตะกั่วทุ่ง",
        "ณ ถลาง",
        "ณ นคร",
        "ณ น่าน",
        "ณ บางช้าง",
        "ณ ป้อมเพชร์",
        "ณ พัทลุง",
        "ณ พิศณุโลก",
        "ณ มโนรม",
        "ณ มหาไชย",
        "ณ ร้อยเอ็จ",
        "ณ ระนอง",
        "ณ ลำปาง",
        "ณ ลำพูน",
        "ณ วิเชียร",
        "ณ สงขลา",
        "ณ หนองคาย",
        "ณ อุบล",
    )
